@@ -35,8 +35,8 @@ from inform import (
 
 
 # Globals {{{1
-__version__ = "0.1.0"
-__released__ = "2020-08-30"
+__version__ = "0.2.0"
+__released__ = "2020-09-02"
 __all__ = ['loads', 'dumps', 'NestedTextError']
 
 # loads {{{1
@@ -139,14 +139,14 @@ class Lines:
                 if list_tag == "".join(components[:2]).lstrip(" "):
                     kind = "list item"
                     value = join_and_dequote(components[2:])
+                elif str_tag == "".join(components[:2]).lstrip(" "):
+                    kind = "string"
+                    value = "".join(components[2:])[:-1]
                 elif dict_tag in components:
                     kind = "dict item"
                     split_loc = components.index(dict_tag)
                     key = join_and_dequote(components[:split_loc])
                     value = join_and_dequote(components[split_loc + 1 :])
-                elif str_tag == "".join(components[:2]).lstrip(" "):
-                    kind = "string"
-                    value = "".join(components[2:])[:-1]
                 else:
                     kind = "unrecognized"
                     value = line
@@ -222,7 +222,7 @@ def read_list(lines, depth):
         if line.depth != depth:
             indentation_error(line, depth)
         if line.kind != "list item":
-            report("expected list item", line)
+            report("expected list item", line, loc=depth)
         if line.value:
             # dbg(line, 'lv')
             data.append(line.value)
@@ -247,13 +247,13 @@ def read_dict(lines, depth):
         if line.depth != depth:
             indentation_error(line, depth)
         if line.kind != "dict item":
-            report("expected dictionary item", line)
+            report("expected dictionary item", line, loc=depth)
+        if line.key in data:
+            report('duplicate key: {}.', line, line.key, loc=depth)
+        if '"' in line.key and "'" in line.key:
+            report("""key must not contain both " and '.""", line, line.key, loc=depth)
         if line.value:
             # dbg(line, 'dv')
-            if line.key in data:
-                report('duplicate key: {}.', line, line.key)
-            if '"' in line.key and "'" in line.key:
-                report("""key must not contain both " and '.""", line, line.key)
             data.update({line.key: line.value})
         else:
             # dbg(line, 'd↵')
@@ -294,22 +294,6 @@ def loads(contents, culprit=None):
     Returns:
         A dictionary or list containing the data.  If contents is empty, an
         empty dictionary is returned.
-
-    **Example**::
-
-        >>> import nestedtext
-        >>> contents = '''
-        ... name: Deryl McKinnon
-        ... phone: 212-590-3107
-        ... '''
-
-        try:
-            data = nestedtext.loads(contents)
-            print(data)
-        except nestedtext.NestedTextError as e:
-            e.report()
-        {'name': 'Deryl McKinnon', 'phone': 'phone: 212-590-3107'}
-
     """
     with set_culprit(culprit):
         lines = Lines(contents)
@@ -317,7 +301,7 @@ def loads(contents, culprit=None):
         type_of_first = lines.type_of_next()
         if type_of_first not in ["list item", "dict item"]:
             if type_of_first:
-                report("expected list or dictionary item.", lines.get_next())
+                report("expected list or dictionary item.", lines.get_next(), loc=0)
             else:
                 return {}
         else:
@@ -370,80 +354,6 @@ def dumps(obj, *, sort_keys=False, indent=4, renderers=None, default=None, level
             this is used to increment the level and so the indent.  Generally
             not specified by the user, but can be useful in unusual situations
             to specify an initial indent.
-
-    **Example**::
-
-        >>> import nestedtext
-
-        >>> try:
-        ...     print(nestedtext.dumps({'a': [0, 1], 'b': [2, 3, 4]}))
-        ... except nestedtext.NestedTextError as e:
-        ...     e.report()
-        a:
-            - 0
-            - 1
-        b:
-            - 2
-            - 3
-            - 4
-
-    *dumps* has built in support for the base Python types of *None*, *bool*,
-    *str*, *float*, *list*, *tuple*, *set*, and *dict*.  If *default* = 'strict'
-    is specified, that list shrinks to *str*, *list*, and *dict*.
-
-    You must make special arrangements to handle objects of other types.  There
-    are two approaches that can be used separately or together. You can specify
-    a default renderer that converts any unknown object type to a string.
-
-    **Example**::
-
-        >>> class Color:
-        ...     def __init__(self, color):
-        ...         self.color = color
-        ...     def __repr__(self):
-        ...         return f'Color({self.color!r})'
-        ...     def __str__(self):
-        ...         return self.color
-
-        >>> data = {'key': 42, 'value': 3.1415926, 'valid': True, 'color': Color('red')}
-        >>> try:
-        ...     print(nestedtext.dumps(data))
-        ... except nestedtext.NestedTextError as e:
-        ...     print(str(e))
-        Color('red'): unsupported type.
-
-        >>> print(nestedtext.dumps(data, default=repr))
-        key: 42
-        value: 3.1415926
-        valid: True
-        color: "Color('red')"
-
-        >>> print(nestedtext.dumps(data, default=str))
-        key: 42
-        value: 3.1415926
-        valid: True
-        color: red
-
-    You may also specify a dictionary of renderers.
-
-    **Example**::
-
-        >>> renderers = {
-        ...     bool: lambda b: 'yes' if b else 'no',
-        ...     int: hex,
-        ...     float: lambda f: f'{f:0.3}',
-        ...     Color: lambda c: c.color,
-        ... }
-
-        >>> try:
-        ...     print(nestedtext.dumps(data, renderers=renderers))
-        ... except nestedtext.NestedTextError as e:
-        ...     e.report()
-        key: 0x2a
-        value: 3.14
-        valid: yes
-        color: red
-
     """
 
     # define sort function
@@ -507,8 +417,7 @@ def dumps(obj, *, sort_keys=False, indent=4, renderers=None, default=None, level
                 return repr(s)
         if (
             len(stripped) < len(s)
-            or '"' in s
-            or "'" in s
+            or s[:1] + s[-1:] in ['""', "''"]
         ):
             return repr(s)
         return s
